@@ -1,6 +1,6 @@
 #Copyright ReportLab Europe Ltd. 2000-2012
 #see license.txt for license details
-__version__ = '$Id: ch1_intro.py 3960 2012-09-27 15:22:33Z guillaume $'
+__version__ = '$Id$'
 from tools.docco.rl_doc_utils import *
 from reportlab.platypus.tableofcontents import TableOfContents
 from datetime import datetime
@@ -183,7 +183,9 @@ disc("""Many people have contributed to ReportLab.  We would like to thank in pa
 Albertas Agejevas, 
 Alex Buck, 
 Andre Reitz, 
+Andrew Cutler,
 Andrew Mercer, 
+Ben Echols,
 Benjamin Dumke,
 Benn B,
 Chad Miller, 
@@ -206,11 +208,15 @@ Jerry Casiano,
 Jorge Godoy,
 Keven D Smith,
 Magnus Lie Hetland,
-Marcel Tromp, Ty Sarna
+Marcel Tromp, 
 Marius Gedminas,
+Matthew Duggan,
+Matthias Kirst,
+Matthias Klose,
 Max M, 
 Michael Egorov,
 Mike Folwell,
+Mirko Dziadzka,
 Moshe Wagner,
 Nate Silva,
 Paul McNett, 
@@ -223,18 +229,21 @@ Robert Hölzl,
 Robert Kern,
 Ron Peleg,
 Simon King,
+Stephan Richter,
 Steve Halasz, 
 T Blatter,
 Tim Roberts,
 Tomasz Swiderski,
+Ty Sarna,
 Volker Haas,
 Yoann Roman, 
 and many more.""")
 
+
 disc("""Special thanks go to Just van Rossum for his valuable assistance with
 font technicalities.""")
 
-disc("""Moshe Wagner and Hosam Aly deserve a huge thanks for contributing to the RTL patch, which is not yet on thr trunk.""")
+disc("""Moshe Wagner and Hosam Aly deserve a huge thanks for contributing to the RTL patch, which is not yet on the trunk.""")
 
 disc("""Marius Gedminas deserves a big hand for contributing the work on TrueType fonts and we
 are glad to include these in the toolkit. Finally we thank Michal Kosmulski for the DarkGarden font
@@ -242,118 +251,13 @@ for and Bitstream Inc. for the Vera fonts.""")
 
 heading2("Installation and Setup")
 
-heading3("A note on available versions")
-disc("""Our website ^http://www.reportlab.com/^ will always have up-to-date
-information on setups and installations. The latest version of the ReportLab library can be found at
-^http://www.reportlab.com/software/opensource/rl-toolkit/download/^.
-Older versions can be found at ^http://www.reportlab.com/ftp/^.
-""")
-disc("""Each successive version is stored in both zip
-and tgz format, but the contents are identical apart from line endings.
-Versions are numbered:  $ReportLab_<major_version>_<minor_version>.zip$, 
-$ReportLab_<major_version>_<minor_version>.tgz$ and so on.
-""")
-disc("""
-The latest stable version is $reportlab2.6$ (.zip or .tgz). 
-Daily snapshots of the trunk are available as
-$reportlab-daily-unix.tar.gz$ or $reportlab-daily-win32.zip$.
-""")
-disc("""Finally, from version 2.4 onwards, there is also a Windows installer
-available for Python versions 2.5 - 2.7, named $ReportLab-2.x.win32-py2.x.exe$
+disc("""To avoid duplication, the installation instructions are kept in the README file
+in our distribution, which can be viewed online at ^http://bitbucket.org/rptlab/reportlab/^""")
+
+disc("""This release (3.0) of ReportLab requires Python versions 2.7, 3.3 or higher.  
+	If you need to use Python 2.5 or 2.6, please use the latest ReportLab 2.x package.
 """)
 
-pencilnote()
-disc("""We plan to drop the support of Python 2.5 in our next release.
-We advise you to move to Python 2.6 or 2.7.
-""")
-
-heading3("Installation on Windows")
-
-restartList()
-
-list("""First, install Python from $http://www.python.org/.$
-Reportlab 2.x works with Python 2.5 upwards but we recommend to use
-the latest stable version of Python 2.7.  
-After installing, you should be able to run the
-'Python (command line)' option from the Start Menu.
-""")
-
-list("""We strongly recommend installing the Python Windows
-Extensions, which gives you access to Windows data sources, COM support, WinAPI calls, and the PythonWin IDE.  This
-can be found at ^http://sourceforge.net/projects/pywin32/^.
-Once this is installed, you can start
-Pythonwin from the Start Menu and get a GUI application.
-""")
-
-list("""Install the Python Imaging Library ($PIL$) from $http://www.pythonware.com/products/pil/$.  This
-step is optional but allows you to include images in your reports.
-""")
-
-list("""Now you are ready to install reportlab itself.  
-The easiest way to do this is to use the .exe installer for Windows, which
-installs both the ReportLab source code and the precompiled DLLs for you.
-""")
-
-list("""
-If, however, you wish to install from source, download and unzip the archive
-from from the downloads page on ^http://www.reportlab.com/^ and copy the $reportlab$ directory
-onto your PythonPath;  You should now be able to go to a Python
-command line interpreter and type $import reportlab$ without getting
-an error message.
-""")
-
-list("""Next, Download the zip file of precompiled DLLs for your Python version from
-the bottom of the downloads page on ^http://www.reportlab.com/^, and unzip
-them into ^C:\Python2x\lib\site-packages^ (or its equivalent for other Python versions
-""")
-
-list("""Open up a $MS-DOS$ command prompt and CD to
-"$reportlab\\..\\tests$".  Enter "$runAll.py$". You should see lots of dots
-and no error messages.  This will also create many PDF files and generate
-the manuals in ^reportlab/docs^ (including this one). """)
-
-list("""
-Finally, we recommend you download and run the script ^rl_check.py^ from
-^http://www.reportlab.com/ftp/^. This will health-check all the above
-steps and warn you if anything is missing or mismatched.""")
-
-heading3("Installation instructions for Unix")
-disc("""
-Many Linux distributions already include or can deliver a ReportLab distribution, although this may be a few months behind our own releases.  On Ubuntu, simply use ^sudo apt-get install python-reportlab^.   In addition, we support the Python packaging mechanisms so you can use ^easy_install reportlab^ in most Python environments.
-""")
-disc("""
-If you want to install the latest version of our code, or to install your own reportlab to go with our commercial distribution, you can install from source as follows:""")
-
-restartList()
-list("""First, install Python.  On a large number of Unix and Linux distributions, Python is already installed,
-or is available as a standard package you can install with the relevant package manager.""")
-
-list("""
-    You will also need to install the Freetype 2 Font Engine, Python Imaging Library, and the gzip library,
-    along with a C compiler.
-""")
-
-list("""You will also need the source code or relevant dev packages for Python and the FreeType 2 Font engine.
-""")
-
-list("""
-Download the latest ReportLab.tgz from the download page on http://www.reportlab.com.
-""")
-
-list("""
-Unpack the archive and follow the instructions in INSTALL.txt.
-""")
-
-list("""You should now be able to run python and execute the python statement
-$import reportlab$ without errors.
-""")
-
-heading3("Instructions for Python novices: Mac")
-disc("""
-This is much, much easier with Mac OS X since Python is installed on your
-system as standard.   Just follow the instructions for installing the ReportLab archive
-above.
-""")
 
 
 heading2("Getting Involved")
@@ -390,6 +294,12 @@ From there you can also browse through the group's archives
 and contributions.  The mailing list is
 the place to report bugs and get support. """)
 
+disc("""The code now lives on BitBucket ($http://bitbucket.org/rptlab/reportlab/$)
+in a Mercurial repository, along with an issue tracker and wiki.  Everyone should
+feel free to contribute, but if you are working actively on some improvements
+or want to draw attention to an issue, please use the mailing list to let us know.""")
+
+
 
 heading2("Site Configuration")
 disc("""There are a number of options which most likely need to be configured globally for a site.
@@ -442,11 +352,6 @@ $http://www.freenetpages.co.uk/hp/alan.gauld/$
 """)
 
 
-bullet("""<b>How to think like a computer scientist</b> (Python version)</b>.
-$http://www.ibiblio.org/obp/thinkCSpy/$
-""")
-
-
 bullet("""<b>Instant Python</b>.
 A 6-page minimal crash course by Magnus Lie Hetland.
 $http://www.hetland.org/python/instant-python.php$
@@ -465,65 +370,31 @@ styles = getStyleSheet()
 indent0_style = styles['Indent0']
 indent1_style = styles['Indent1']
 
-heading2("Goals for the 2.x series")
-disc("""The main rationale for 2.0 was an incompatible change at the character level:
-to properly support Unicode input. Now that it's out we will maintain compatibility
-with 2.0. There are no pressing feature wishlists and new features will be driven,
-as always, by contributions and the demands of projects.""")
+heading2("Goals for the 3.x release series")
+disc("""ReportLab 3.0 has been produced to help in the migration to Python 3.x.  Python 3.x will
+be standard in future Ubuntu releases and is gaining popularity, and a good proportion
+of major Python packages now run on Python 3.  """)
 
-disc("""One area where we do want to make progress from release to release is with documentation
-and installability. We'll be looking into better support for distutils, setuptools,
-eggs and so on; and into better examples and tools to help people learn what's in the
-(substantial) code base.""")
 
-disc("""
-Bigger ideas and more substantial rewrites are deferred to Version 3.0, with no particular
-target dates.
-""")
 
-heading2("What's New in ReportLab 2.6")
-disc("""This is a minor release focusing mainly on improved documentation. There are a 
-number of minor enhancements, and a larger number of previous-undocumented
-enhancements which we have documented better.""")
+bullet("""Python 3.x compatibility.  A single line of code should run on 2.7 and 3.3""")
+bullet(""" __init__.py restricts to 2.7 or >=3.3""")
+bullet("""__init__.py allow the import of on optional reportlab.local_rl_mods to allow monkey patching etc.""")
+bullet("""rl_config now imports rl_settings & optionally local_rl_settings""")
+bullet("""ReportLab C extensions now live inside reportlab; _rl_accel is no longer required. All _rl_accel imports now pass through reportlab.lib.rl_accel""")
+bullet("""xmllib is gone, alongside the paraparser stuff that caused issues in favour of HTMLParser.""")
+bullet("""some obsolete C extensions (sgmlop and pyHnj) are gone""")
+bullet("""Improved support for multi-threaded systems to the _rl_accel C extension module.""")
+bullet("""Removed reportlab/lib/ para.py & pycanvas.py.  These would better belong in third party packages, which can make use of the monkeypatching feature above.""")
+bullet("""Add ability to output greyscale and 1-bit PIL images without conversion to RGB. (contributed by Matthew Duggan)""")
+bullet("""highlight annotation (contributed by Ben Echols)""")
+bullet("""full compliance with pip, easy_install, wheels etc""")
 
-disc("""A big thanks goes to the community for their help in reporting bugs and providing patches. 
-Thanks to everybody who has contributed to the open-source toolkit in the run-up to the 2.6 release, 
-whether by reporting bugs, sending patches, or contributing to the reportlab-users mailing list. 
-Thanks especially to the following people: Alex Buck, Felix Labrecque,
-Peter Johnson, James Martin-Collar and Guillaume Francois.
-This page documents what has changed since version 2.5.""")
 
-disc('Reportlab 2.6 is installable with easy_install. You must have installed a compatible C compiler and the dependencies such as Freetype and PIL.')
 
-heading4('General changes')
-bullet("""Manuals have been reformatted with more pleasing code snippets and tables of 
-contents, and reviewed and expanded.""")
 
-heading4('Flowing documents (Platypus)')
-bullet("""Added support for HTML-style list objects.""")
-bullet("""Added flexible mechanism for drawing bullets.""")
-bullet("""Allowed XPreformatted objects to use Asian line wrapping.""")
-bullet("""Added an 'autoNextPageTemplate' attribute to PageTemplates. For example you 
-can now set up a 'chapter first page template' which will always be followed
-by a 'continuation template' on the next page break, saving the programmer from
-having to issue control flow commands in the story.""")
-bullet("""Added a TopPadder flowable, which will 'wrap' another Flowable and move it 
-to the bottom of the current page.""")
-bullet("""More helpful error messages when large tables cannot be rendered.""")
-bullet("""Documentation for images within text (test_032_images).""")
-bullet("""Trailing dots for use on contents pages.""")
+disc("""Detailed release notes are available at 
+$http://www.reportlab.com/software/documentation/relnotes/30/$""")
+
 
-heading4('Charts and graphics')
-bullet("""Support for UPCA bar codes.""")
-bullet("""We now have a semi-intelligent system for labelling pie charts with 
-callout lines.  Thanks to James Martin-Collar, a maths student at Warwick 
-University, who did this as his summer internship.""")
-bullet("""Axes - added startOffset and endOffset properties; allowed for axis 
-background annotations.""")
-bullet("""Bar charts - allow more control of z Index (i.e. drawing order of axes and
-lines)""")
-bullet("""Pie charts - fixed bugs in 3d appearance.""")
-bullet("""SVG output back end has seen some bugs fixed and now outputs resizeable SVG.""")
 
-# Noteworthy bug fixes Section #######################
-#heading3("Noteworthy bug fixes")
